       use Lingua::Romana::Perligata;

           EGRESSO SCRIBE DICTUM
   SIC PLEASE ENTER THE STRING TO BE CIS
           TUM LACUNAM TUM DICTUM

 SIC SEARCHED FOR THE STRING MONKEY CIS TUM
           BIGUTTAM TUM LACUNAM.
      HUIC VESTIBULO PERLEGEMENTUM DA.

      DICTUM SIC STRING MONKEY WAS CIS
        TUM LACUNAM SCRIBE EGRESSO.
                   SI HOC
       TUM DICEMENTUM SIC MONKEY CIS
          SCRUTAMENTUM TUM NULLUM

                PRAESTANTIAM
     HOCQUE TUM DEMINUEMENTUM DICEMENTUM
        SIC MONKEY CIS SCRUTAMENTUM

        TUM NULLUM PRAESTANTIAM FAC
      SIC EGRESSO NOT INQUEMENTUM TUM
            LACUNAM SCRIBE CIS.

           SCRIBE EGRESSO DICTUM
   SIC FOUND IN THE INPUT STRING CIS TUM
                NOVUMVERSUM.
