print "1..10\n";

use Lingua::Romana::Perligata;

PER NEXTUM IN UNAM TUM X CONSCRIBEMENTIS FAC SIC
    NEXTUM OUTE.
CIS

OUTERE SIC
    SCRIBE EGRESSO ok TUM LACUNAM TUM NULLIMUM HORUM TUM NOVUMVERSUM.
CIS

